"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const vitest_1 = require("vitest");
const Bank_1 = __importDefault(require("../src/structures/Bank"));
const Items_1 = __importDefault(require("../src/structures/Items"));
const util_1 = require("../src/util");
(0, vitest_1.describe)('Bank', () => {
    (0, vitest_1.test)('convert string bank to number bank', () => {
        vitest_1.expect.assertions(1);
        const strBank = {
            Toolkit: 2,
            'Ammo Mould': 4,
            Candle: 1
        };
        const numBank = {
            1: 2,
            4: 4,
            36: 1
        };
        (0, vitest_1.expect)((0, util_1.resolveNameBank)(strBank)).toEqual(numBank);
    });
    (0, vitest_1.test)('convert loot item array to number bank', () => {
        vitest_1.expect.assertions(1);
        const lootItems = [
            {
                item: 6,
                quantity: 2
            },
            {
                item: 67,
                quantity: 2
            },
            {
                item: 6,
                quantity: 8
            },
            {
                item: 32,
                quantity: 1
            }
        ];
        const expected = {
            6: 10,
            32: 1,
            67: 2
        };
        (0, vitest_1.expect)((0, util_1.bankFromLootTableOutput)(lootItems)).toEqual(expected);
    });
    (0, vitest_1.test)('bank contains item', () => {
        vitest_1.expect.assertions(4);
        const bank = { 1: 2, 3: 4 };
        (0, vitest_1.expect)((0, util_1.bankHasItem)(bank, 1)).toBeTruthy();
        (0, vitest_1.expect)((0, util_1.bankHasItem)(bank, 2)).toBeFalsy();
        (0, vitest_1.expect)((0, util_1.bankHasItem)(bank, 3, 3)).toBeTruthy();
        (0, vitest_1.expect)((0, util_1.bankHasItem)(bank, 1, 4)).toBeFalsy();
    });
    (0, vitest_1.test)('bank has all items', () => {
        vitest_1.expect.assertions(2);
        const bankToHave = (0, util_1.resolveNameBank)({
            'Fire rune': 1000,
            'Air rune': 1,
            'Chaos rune': 101010
        });
        const bankThatShouldntHave = (0, util_1.resolveNameBank)({
            'Fire rune': 1000,
            'Air rune': 1,
            'Chaos rune': 1
        });
        const bankThatShouldHave = (0, util_1.resolveNameBank)({
            'Fire rune': 104200,
            'Air rune': 43432,
            'Chaos rune': 121010,
            'Death rune': 121010
        });
        (0, vitest_1.expect)((0, util_1.bankHasAllItemsFromBank)(bankThatShouldHave, bankToHave)).toBeTruthy();
        (0, vitest_1.expect)((0, util_1.bankHasAllItemsFromBank)(bankThatShouldntHave, bankToHave)).toBeFalsy();
    });
    (0, vitest_1.test)('remove item from bank', () => {
        vitest_1.expect.assertions(3);
        const bank = {
            45: 9,
            87: 1
        };
        (0, vitest_1.expect)((0, util_1.removeItemFromBank)(bank, 87)).toEqual({
            45: 9
        });
        (0, vitest_1.expect)((0, util_1.removeItemFromBank)(bank, 98, 1)).toEqual({
            45: 9,
            87: 1
        });
        (0, vitest_1.expect)((0, util_1.removeItemFromBank)(bank, 45, 2)).toEqual({
            45: 7,
            87: 1
        });
    });
    (0, vitest_1.test)('remove bank from bank', () => {
        vitest_1.expect.assertions(1);
        const sourceBank = (0, util_1.resolveNameBank)({
            'Fire rune': 100,
            'Air rune': 50
        });
        const bankToRemove = (0, util_1.resolveNameBank)({
            'Fire rune': 50,
            'Air rune': 50
        });
        const expectedBank = (0, util_1.resolveNameBank)({
            'Fire rune': 50
        });
        (0, vitest_1.expect)((0, util_1.removeBankFromBank)(sourceBank, bankToRemove)).toEqual(expectedBank);
    });
    (0, vitest_1.test)('add item to bank', () => {
        vitest_1.expect.assertions(2);
        const bank = {
            45: 9,
            87: 1
        };
        const expected = {
            45: 9,
            69: 420,
            87: 1
        };
        const expectedInc = {
            45: 9,
            87: 2
        };
        (0, vitest_1.expect)((0, util_1.addItemToBank)(bank, 69, 420)).toEqual(expected);
        (0, vitest_1.expect)((0, util_1.addItemToBank)(bank, 87)).toEqual(expectedInc);
    });
    (0, vitest_1.test)('add bank to bank', () => {
        vitest_1.expect.assertions(1);
        const bank = { 1: 2 };
        const bank2 = { 3: 4 };
        const expected = { 1: 2, 3: 4 };
        (0, vitest_1.expect)(new Bank_1.default(bank).add(bank2).bank).toEqual(expected);
    });
    (0, vitest_1.test)('add array of items to bank', () => {
        vitest_1.expect.assertions(1);
        const bank = { 1: 2 };
        const items = [3, 4, 5];
        const expected = { 1: 2, 3: 1, 4: 1, 5: 1 };
        (0, vitest_1.expect)((0, util_1.addArrayToBank)(bank, items)).toEqual(expected);
    });
    (0, vitest_1.test)('add item to bank', () => {
        const bank = new Bank_1.default();
        const item = Items_1.default.get('Twisted bow');
        bank.add(item);
        (0, vitest_1.expect)(bank.equals(new Bank_1.default().add('Twisted bow'))).toBeTruthy();
        bank.add(item);
        (0, vitest_1.expect)(bank.equals(new Bank_1.default().add('Twisted bow', 2))).toBeTruthy();
    });
    (0, vitest_1.test)('multiply bank items', () => {
        const bank = { 1: 2, 3: 4 };
        const expected = { 1: 4, 3: 8 };
        (0, vitest_1.expect)((0, util_1.multiplyBank)(bank, 2)).toEqual(expected);
    });
    (0, vitest_1.test)('multiply bank items, excluded', () => {
        const bank = new Bank_1.default().add('Coal', 100).add('Trout', 100).add('Egg', 100).add('Bones', 100);
        bank.add(undefined);
        const expected = new Bank_1.default().add('Coal', 200).add('Trout', 100).add('Egg', 100).add('Bones', 200);
        (0, vitest_1.expect)(bank.multiply(2, ['Trout', 'Egg'].map(util_1.itemID))).toEqual(expected);
        (0, vitest_1.expect)(bank.amount('Coal')).toEqual(200);
        (0, vitest_1.expect)(bank.amount('Egg')).toEqual(100);
    });
    (0, vitest_1.test)('numItemsBankHasInBank', () => {
        vitest_1.expect.assertions(2);
        const sourceBank1 = { 1: 2, 3: 4 };
        const bankToHave1 = { 1: 4, 3: 8 };
        (0, vitest_1.expect)((0, util_1.numItemsBankHasInBank)(sourceBank1, bankToHave1)).toEqual(2);
        const sourceBank2 = { 1: 0, 3: 4 };
        const bankToHave2 = { 1: 4, 3: 8 };
        (0, vitest_1.expect)((0, util_1.numItemsBankHasInBank)(sourceBank2, bankToHave2)).toEqual(1);
    });
    (0, vitest_1.test)('mutate filter', () => {
        const bank = new Bank_1.default({
            Toolkit: 2,
            'Ammo Mould': 4,
            Candle: 1
        });
        (0, vitest_1.expect)(bank.length).toEqual(3);
        const empty = bank.filter(() => false);
        (0, vitest_1.expect)(bank.length).toEqual(3);
        (0, vitest_1.expect)(empty.length).toEqual(0);
        bank.filter(item => item.name === 'Candle', true);
        (0, vitest_1.expect)(bank.length).toEqual(1);
    });
    (0, vitest_1.test)('value', () => {
        const bank = new Bank_1.default({
            Toolkit: 2
        });
        (0, vitest_1.expect)(bank.value()).toEqual(0);
        const runePlatebody = Items_1.default.get('Rune platebody');
        const bank2 = new Bank_1.default({
            'Rune platebody': 10
        });
        (0, vitest_1.expect)(runePlatebody.price).toBeGreaterThan(25000);
        (0, vitest_1.expect)(bank2.value()).toEqual(runePlatebody.price * 10);
        const bank3 = new Bank_1.default({
            'Rune platebody': 10,
            'Rune platelegs': 10,
            'Rune boots': 10,
            Toolkit: 1,
            'Abyssal book': 10000
        });
        (0, vitest_1.expect)(runePlatebody.price).toBeGreaterThan(25000);
        (0, vitest_1.expect)(bank3.value()).toEqual(runePlatebody.price * 10 + Items_1.default.get('Rune platelegs').price * 10 + Items_1.default.get('Rune boots').price * 10);
    });
    (0, vitest_1.test)('init from bank', () => {
        const start = { 1: 1 };
        let bank = new Bank_1.default(start);
        const bankToTest = new Bank_1.default(bank);
        delete start[1];
        delete bank.bank[1];
        start[2] = 1;
        bank.bank[2] = 1;
        bank = bank.multiply(100);
        bank.bank = {};
        (0, vitest_1.expect)(bankToTest.amount(1)).toEqual(1);
        (0, vitest_1.expect)(bankToTest.length).toEqual(1);
    });
    (0, vitest_1.test)('frozen bank', () => {
        const bank = new Bank_1.default().add('Twisted bow', 73).add('Egg', 5);
        bank.freeze();
        try {
            bank.bank[5] = 1;
        }
        catch (_a) { }
        (0, vitest_1.expect)(bank.length).toEqual(2);
        (0, vitest_1.expect)(() => bank.add('Twisted bow')).toThrowError();
        try {
            bank.add('Twisted bow');
        }
        catch (_b) { }
        try {
            bank.addItem((0, util_1.itemID)('Twisted bow'));
        }
        catch (_c) { }
        try {
            bank.remove((0, util_1.itemID)('Twisted bow'));
        }
        catch (_d) { }
        try {
            bank.multiply(5);
        }
        catch (_e) { }
        try {
            bank.filter(() => true, true);
        }
        catch (_f) { }
        (0, vitest_1.expect)(bank.amount('Twisted bow')).toEqual(73);
    });
    (0, vitest_1.test)('equals', () => {
        const bank = new Bank_1.default().add('Twisted bow', 73).add('Egg', 5);
        bank.add(undefined);
        bank.add({});
        bank.add(new Bank_1.default());
        bank.remove({});
        bank.remove(new Bank_1.default());
        (0, vitest_1.expect)(bank.equals(new Bank_1.default())).toEqual(false);
        (0, vitest_1.expect)(bank.equals(new Bank_1.default().add('Twisted bow', 73).add('Egg', 4))).toEqual(false);
        (0, vitest_1.expect)(bank.equals(new Bank_1.default().add('Twisted bow', 73).add('Egg', 5).add('Coal'))).toEqual(false);
        (0, vitest_1.expect)(bank.equals(new Bank_1.default().add('Twisted bow', 73).add('Egg', 5))).toEqual(true);
        const bank2 = new Bank_1.default().add('Twisted bow');
        (0, vitest_1.expect)(bank2.equals(new Bank_1.default())).toEqual(false);
        (0, vitest_1.expect)(bank2.equals(new Bank_1.default().add('Coal'))).toEqual(false);
        (0, vitest_1.expect)(bank2.equals(new Bank_1.default().add('Twisted bow', 2))).toEqual(false);
        (0, vitest_1.expect)(bank2.equals(new Bank_1.default().add('Twisted bow', 1).add('Coal'))).toEqual(false);
        (0, vitest_1.expect)(bank2.equals(bank2)).toEqual(true);
    });
    (0, vitest_1.test)('difference', () => {
        const bank = new Bank_1.default().add('Twisted bow', 73).add('Egg', 5);
        bank.add(undefined);
        bank.add({});
        bank.add(new Bank_1.default());
        (0, vitest_1.expect)(bank.difference(new Bank_1.default()).equals(bank)).toBeTruthy();
        const bank2 = new Bank_1.default().add('Twisted bow', 73).add('Egg', 5);
        (0, vitest_1.expect)(bank2.difference(new Bank_1.default().add('Twisted bow', 72).add('Egg', 5)).equals(new Bank_1.default().add('Twisted bow', 1))).toBeTruthy();
    });
    (0, vitest_1.test)('random', () => {
        const bank = new Bank_1.default().add('Twisted bow', 73).add('Egg', 5);
        (0, vitest_1.expect)(bank.random()).toBeTruthy();
        (0, vitest_1.expect)(new Bank_1.default().random()).toBeFalsy();
    });
});
//# sourceMappingURL=Bank.test.js.map