"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const vitest_1 = require("vitest");
const src_1 = require("../src");
const util_1 = require("../src/util");
const TestLootTable = new src_1.LootTable().add('Toolkit');
(0, vitest_1.describe)('Bank Class', () => {
    (0, vitest_1.test)('adding', () => {
        const bank = new src_1.Bank({ 1: 1 });
        (0, vitest_1.expect)(bank.amount(1)).toBe(1);
        bank.add(1, 1);
        (0, vitest_1.expect)(bank.amount(1)).toBe(2);
        (0, vitest_1.expect)(bank.amount('Toolkit')).toBe(2);
        (0, vitest_1.expect)(bank.amount('Twisted bow')).toBe(0);
        (0, vitest_1.expect)(bank.bank).toEqual({ 1: 2 });
    });
    (0, vitest_1.test)('removing', () => {
        const bank = new src_1.Bank({ 1: 1 });
        (0, vitest_1.expect)(bank.amount(1)).toBe(1);
        bank.remove(1, 1);
        (0, vitest_1.expect)(bank.amount(1)).toBe(0);
        (0, vitest_1.expect)(bank.amount('Toolkit')).toBe(0);
        (0, vitest_1.expect)(bank.bank).toEqual({});
        bank.add({ Coal: 1, Emerald: 1, Ruby: 1 });
        bank.remove({ Coal: 9999, Emerald: 9999, Toolkit: 10000 });
        (0, vitest_1.expect)(bank.bank).toEqual({ 1603: 1 });
    });
    (0, vitest_1.test)('chaining', () => {
        const bank = new src_1.Bank().add(1).remove(1).add(1);
        (0, vitest_1.expect)(bank.amount(1)).toBe(1);
    });
    (0, vitest_1.test)('multiply', () => {
        const bank = new src_1.Bank({ 1: 1, 2: 1, 3: 1, 4: 1 });
        bank.multiply(10);
        (0, vitest_1.expect)(bank.amount(1)).toBe(10);
        (0, vitest_1.expect)(bank.amount(2)).toBe(10);
        (0, vitest_1.expect)(bank.amount(3)).toBe(10);
        (0, vitest_1.expect)(bank.amount(4)).toBe(10);
    });
    (0, vitest_1.test)('random', () => {
        const bank = new src_1.Bank({ 69: 420 });
        const random = bank.random();
        (0, vitest_1.expect)(random).toEqual({ id: 69, qty: 420 });
    });
    (0, vitest_1.test)('ReturnedLootItem', () => {
        const items = [
            { item: 1, quantity: 5 },
            { item: 1, quantity: 5 },
            { item: 1, quantity: 0 },
            { item: 2, quantity: 10 }
        ];
        const bank = new src_1.Bank().add(items);
        (0, vitest_1.expect)(bank.bank).toEqual({ 1: 10, 2: 10 });
        bank.remove(items);
        (0, vitest_1.expect)(bank.bank).toEqual({});
        (0, vitest_1.expect)(bank.amount(1)).toBe(0);
        (0, vitest_1.expect)(bank.amount(2)).toBe(0);
    });
    (0, vitest_1.test)('other', () => {
        const bank = new src_1.Bank().add(1).add(1).add(1).add(1);
        (0, vitest_1.expect)(bank.amount(1)).toBe(4);
        bank.remove({ 1: 4 });
        (0, vitest_1.expect)(bank.amount(1)).toBe(0);
        bank.add({ Toolkit: 4 });
        (0, vitest_1.expect)(bank.amount(1)).toBe(4);
        bank.remove({ Toolkit: 4 });
        (0, vitest_1.expect)(bank.amount(1)).toBe(0);
        bank.add(TestLootTable.roll());
        (0, vitest_1.expect)(bank.amount(1)).toBe(1);
        bank.add(new src_1.Bank({ 1: 1 }));
        (0, vitest_1.expect)(bank.amount(1)).toBe(2);
        bank.add(new src_1.Bank({ 1: 0 }));
        (0, vitest_1.expect)(bank.amount(1)).toBe(2);
        bank.remove(new src_1.Bank({ 1: 1 }));
        bank.add(new src_1.Bank({}));
        bank.add({});
        (0, vitest_1.expect)(bank.amount(1)).toBe(1);
    });
    (0, vitest_1.test)('has', () => {
        const source = (0, util_1.resolveNameBank)({
            Coal: 100,
            'Monkey nuts': 100,
            Ruby: 100
        });
        const bank = new src_1.Bank(source);
        (0, vitest_1.expect)(bank.has('Coal')).toBe(true);
        (0, vitest_1.expect)(bank.has('Ruby')).toBe(true);
        (0, vitest_1.expect)(bank.has((0, util_1.itemID)('Monkey nuts'))).toBe(true);
        (0, vitest_1.expect)(bank.has((0, util_1.itemID)('Emerald'))).toBe(false);
        (0, vitest_1.expect)(bank.has('Emerald')).toBe(false);
        (0, vitest_1.expect)(bank.has(['Coal'])).toBe(true);
        (0, vitest_1.expect)(bank.has(['Coal', 'Ruby', 'Monkey nuts'])).toBe(true);
        (0, vitest_1.expect)(bank.has(['Emerald'])).toBe(false);
        (0, vitest_1.expect)(bank.has(['Coal', 'Ruby', 'Monkey nuts', 'Emerald'])).toBe(false);
        (0, vitest_1.expect)(bank.has(source)).toBe(true);
        (0, vitest_1.expect)(bank.has({ Emerald: 1 })).toBe(false);
        (0, vitest_1.expect)(bank.has(bank)).toBe(true);
        (0, vitest_1.expect)(bank.has(bank.clone().add('Egg'))).toBe(false);
    });
    (0, vitest_1.test)('toString', () => {
        const bank = new src_1.Bank((0, util_1.resolveNameBank)({ Coal: 20, Egg: 5000, Emerald: 1, Ruby: 20000 }));
        bank.add('Twisted bow', 0);
        (0, vitest_1.expect)(bank.toString()).toEqual('20,000x Ruby, 5,000x Egg, 20x Coal, 1x Emerald');
        (0, vitest_1.expect)(bank.length).toEqual(4);
        bank.add('3rd age platebody', 2);
        (0, vitest_1.expect)(bank.toString()).toEqual('20,000x Ruby, 5,000x Egg, 20x Coal, 2x 3rd age platebody, 1x Emerald');
        (0, vitest_1.expect)(bank.length).toEqual(5);
        (0, vitest_1.expect)(new src_1.Bank().toString()).toEqual('No items');
        (0, vitest_1.expect)(new src_1.Bank({ 111231231: 1 }).toString()).toEqual('1x Unknown item');
    });
    (0, vitest_1.test)('.items()', () => {
        const bank = new src_1.Bank((0, util_1.resolveNameBank)({ Coal: 20, Egg: 5000, Emerald: 1, Ruby: 20000 }));
        const actual = bank.items();
        const expected = [
            [src_1.Items.get('Coal'), 20],
            [src_1.Items.get('Egg'), 5000],
            [src_1.Items.get('Emerald'), 1],
            [src_1.Items.get('Ruby'), 20000]
        ];
        (0, vitest_1.expect)(actual).toEqual(vitest_1.expect.arrayContaining(expected));
        (0, vitest_1.expect)(expected).toEqual(vitest_1.expect.arrayContaining(actual));
    });
    (0, vitest_1.test)('dont mutate', () => {
        const base = (0, util_1.resolveNameBank)({ Coal: 5 });
        const bank = new src_1.Bank(base);
        bank.add('Coal', 500);
        bank.add('Egg', 100);
        (0, vitest_1.expect)(Object.keys(base).length).toEqual(1);
        const testBank = new src_1.Bank(base);
        (0, vitest_1.expect)(testBank.amount('Coal')).toEqual(5);
        (0, vitest_1.expect)(testBank.amount('Egg')).toEqual(0);
    });
    (0, vitest_1.test)('.forEach()', () => {
        const bank = new src_1.Bank((0, util_1.resolveNameBank)({ Coal: 20, Egg: 5000, Emerald: 1, Ruby: 20000 }));
        const mockCallback = vitest_1.vi.fn();
        bank.forEach(mockCallback);
        (0, vitest_1.expect)(mockCallback).toHaveBeenCalledTimes(bank.length);
        (0, vitest_1.expect)(mockCallback).toHaveBeenCalledWith(src_1.Items.get('Coal'), 20);
    });
    (0, vitest_1.test)('.filter()', () => {
        const baseBank = (0, util_1.resolveNameBank)({
            Coal: 20,
            Egg: 5000,
            Emerald: 1,
            Ruby: 20000,
            Toolkit: 1
        });
        const bank = new src_1.Bank(baseBank);
        const cb = vitest_1.vi.fn((item) => Boolean(item.tradeable));
        const filtered = bank.filter(cb);
        (0, vitest_1.expect)(cb).toHaveBeenCalledTimes(bank.length);
        (0, vitest_1.expect)(cb).toHaveBeenCalledWith(src_1.Items.get('Coal'), 20);
        (0, vitest_1.expect)(filtered.length).toEqual(bank.length - 1);
        (0, vitest_1.expect)(filtered.amount('Toolkit')).toEqual(0);
        (0, vitest_1.expect)(bank.amount('Toolkit')).toEqual(1);
    });
    (0, vitest_1.test)('.clone()', () => {
        const baseBank = (0, util_1.resolveNameBank)({
            Coal: 20,
            Egg: 5000,
            Emerald: 1,
            Ruby: 20000,
            Toolkit: 1
        });
        const bank = new src_1.Bank(baseBank);
        const cloned = bank.clone();
        cloned.remove('Coal', 20);
        (0, vitest_1.expect)(cloned.amount('Coal')).toEqual(0);
        (0, vitest_1.expect)(bank.amount('Coal')).toEqual(20);
    });
    (0, vitest_1.test)('.fits()', () => {
        const baseBank = (0, util_1.resolveNameBank)({
            Coal: 20,
            Egg: 5000,
            Emerald: 1,
            Ruby: 20000,
            Toolkit: 1
        });
        const bank = new src_1.Bank(baseBank);
        (0, vitest_1.expect)(bank.fits(bank)).toEqual(1);
        const b1 = new src_1.Bank((0, util_1.multiplyBank)(bank.bank, 2));
        (0, vitest_1.expect)(b1.fits(bank)).toEqual(2);
        const b2 = new src_1.Bank((0, util_1.resolveNameBank)({ Coal: 1 }));
        (0, vitest_1.expect)(bank.fits(b2)).toEqual(20);
        const b3 = new src_1.Bank((0, util_1.resolveNameBank)({ Coal: 1, Emerald: 5 }));
        (0, vitest_1.expect)(bank.fits(b3)).toEqual(0);
        const b4 = new src_1.Bank((0, util_1.resolveNameBank)({ Coal: 1, Ruby: 10000 }));
        (0, vitest_1.expect)(bank.fits(b4)).toEqual(2);
        const b5 = new src_1.Bank((0, util_1.resolveNameBank)({ Coal: 1, 'Twisted bow': 5 }));
        (0, vitest_1.expect)(bank.fits(b5)).toEqual(0);
        const b6 = new src_1.Bank((0, util_1.resolveNameBank)({ Coal: 10, Ruby: 10000 }));
        (0, vitest_1.expect)(bank.fits(b6)).toEqual(2);
        const b7 = new src_1.Bank((0, util_1.resolveNameBank)({ Coal: 11, Ruby: 10000 }));
        (0, vitest_1.expect)(bank.fits(b7)).toEqual(1);
        (0, vitest_1.expect)(b7.fits(bank)).toEqual(0);
        const b8 = new src_1.Bank().add('Coal', 100).add('Ruby', 100);
        (0, vitest_1.expect)(b8.fits(new src_1.Bank().add('Coal', 100).add('Ruby', 1))).toEqual(1);
        (0, vitest_1.expect)(b8.fits(new src_1.Bank().add('Coal', 500).add('Ruby', 1))).toEqual(0);
        (0, vitest_1.expect)(bank.fits(new src_1.Bank())).toEqual(0);
    });
    (0, vitest_1.test)('resolving initial bank', () => {
        const baseBank = {
            Coal: 20,
            Egg: 5000,
            Emerald: 1,
            Ruby: 20000,
            Toolkit: 1
        };
        const idVersion = (0, util_1.resolveNameBank)(baseBank);
        const bank = new src_1.Bank(baseBank);
        (0, vitest_1.expect)(bank.amount('Coal')).toEqual(20);
        (0, vitest_1.expect)(bank.bank).toEqual(idVersion);
        (0, vitest_1.expect)(bank.has(idVersion)).toBeTruthy();
        const otherBank = new src_1.Bank(idVersion);
        (0, vitest_1.expect)(otherBank.amount('Coal')).toEqual(20);
        (0, vitest_1.expect)(otherBank.bank).toEqual(bank.bank);
        (0, vitest_1.expect)(otherBank.has(idVersion)).toBeTruthy();
        const base = {
            'Bandos chestplate': 4,
            'Bandos tassets': 1,
            'Helm of neitiznot': 2,
            'Justiciar faceguard': 1,
            'Dragon scimitar': 1,
            '3rd age amulet': 1,
            'Occult necklace': 1,
            'Ancestral robe top': 1,
            'Ancestral robe bottom': 1,
            'Dragonfire shield': 1,
            'Amulet of glory': 1,
            'Blade of saeldor': 0
        };
        (0, vitest_1.expect)(new src_1.Bank(base).bank).toEqual((0, util_1.resolveNameBank)(base));
    });
    (0, vitest_1.test)('freeze bank', () => {
        const bank = new src_1.Bank().add('Twisted bow').freeze();
        (0, vitest_1.expect)(() => bank.add('Coal')).toThrow();
        (0, vitest_1.expect)(() => (bank.bank[(0, util_1.itemID)('Coal')] = 1)).toThrow();
        (0, vitest_1.expect)(() => delete bank.bank[(0, util_1.itemID)('Twisted bow')]).toThrow();
        (0, vitest_1.expect)(bank.bank).toEqual({ [(0, util_1.itemID)('Twisted bow')]: 1 });
    });
});
//# sourceMappingURL=BankClass.test.js.map