"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const vitest_1 = require("vitest");
const src_1 = require("../src");
const types_1 = require("../src/meta/types");
const expectedIDTuple = [
    ['Coins', 995],
    ['Clue scroll (beginner)', 23182],
    ['Clue scroll (easy)', 2677],
    ['Clue scroll (medium)', 2801],
    ['Clue scroll (hard)', 2722],
    ['Clue scroll (elite)', 12073],
    ['Clue scroll (master)', 19835],
    ['Reward casket (beginner)', 23245],
    ['Reward casket (easy)', 20546],
    ['Reward casket (medium)', 20545],
    ['Reward casket (hard)', 20544],
    ['Reward casket (elite)', 20543],
    ['Reward casket (master)', 19836],
    // Random
    ['Air rune', 556],
    ["Zulrah's scales", 12934],
    ['Bones', 526],
    ['Cannonball', 2],
    ['Opal bolt tips', 45],
    ['Runite bolts', 9144],
    ['Sapphire bolt tips', 9189],
    ['Onyx bolts (e)', 9245],
    ['Runite bolts (unf)', 9381],
    ['Dragon arrow', 11212],
    ['Dragon dart tip', 11232],
    ['Dragon arrowtips', 11237],
    ['Armadyl hilt', 11810],
    ['Godsword shard 1', 11818],
    ['Elysian sigil', 12819],
    // Clue
    ['Spiked manacles', 23389],
    ['Adamant platebody (h1)', 23392],
    ['Adamant platebody (h2)', 23395],
    ['Adamant platebody (h3)', 23398],
    ['Adamant platebody (h4)', 23401],
    ['Adamant platebody (h5)', 23404],
    ['Wolf mask', 23407],
    ['Wolf cloak', 23410],
    ['Climbing boots (g)', 23413],
    ['Ring of endurance (uncharged)', 24844]
];
// Check that items have the ID that we expect them to have, and not some random other version of that item.
function checkItems() {
    for (const [itemName, itemID] of expectedIDTuple) {
        const item = src_1.Items.get(itemName);
        if (!item) {
            throw new Error(`*ERROR*: ${itemName} doesnt exist?`);
        }
        if (item.id !== itemID) {
            throw new Error(`*ERROR*: ${itemName} has the wrong item ID! Is[${item.id}] ShouldBe[${itemID}]`);
        }
    }
}
(0, vitest_1.describe)('Items', () => {
    (0, vitest_1.test)('All openables must have the ID of a real item', () => {
        for (const openable of src_1.Openables.values()) {
            (0, vitest_1.expect)(src_1.Items.get(openable.id)).toBeTruthy();
        }
    });
    (0, vitest_1.beforeAll)(() => {
        checkItems();
    });
    vitest_1.test.concurrent('Fetching Item by ID', () => __awaiter(void 0, void 0, void 0, function* () {
        const [tbow, superStr, dragonDagger, coins] = [
            src_1.Items.get(20997),
            src_1.Items.get(2440),
            src_1.Items.get('dragon dagger(p++)'),
            src_1.Items.get('Coins')
        ];
        if (!tbow)
            throw new Error('Missing item.');
        (0, vitest_1.expect)(tbow.id).toBe(20997);
        (0, vitest_1.expect)(tbow.name).toBe('Twisted bow');
        (0, vitest_1.expect)(tbow.price).toBeGreaterThan(800000000);
        if (!superStr)
            throw new Error('Missing item.');
        (0, vitest_1.expect)(superStr.id).toBe(2440);
        if (!dragonDagger)
            throw new Error('Missing item.');
        (0, vitest_1.expect)(dragonDagger.id).toBe(5698);
        (0, vitest_1.expect)(dragonDagger.name).toBe('Dragon dagger(p++)');
        (0, vitest_1.expect)(dragonDagger.price).toBeLessThan(26000);
        if (!coins)
            throw new Error('Missing item.');
        (0, vitest_1.expect)(coins.id).toBe(995);
        (0, vitest_1.expect)(coins.price).toEqual(1);
        (0, vitest_1.expect)(src_1.Items.get('Snowy knight').price).toEqual(0);
        (0, vitest_1.expect)(src_1.Items.get('Vial of blood').id).toEqual(22446);
    }), 60000);
    vitest_1.test.concurrent.each(["Zulrah's scales", 'Belladonna seed'])('Duplicate/Stacked item counts', itemName => {
        const itemArr = src_1.Items.filter(i => i.name === itemName).array();
        (0, vitest_1.expect)(itemArr.length !== 1).toBeFalsy();
        const item = itemArr[0];
        if (!item || !item.tradeable || !item.highalch) {
            throw new Error(`Invalid item for ${itemName}?`);
        }
    }, 60000);
    vitest_1.test.concurrent('Equipment', () => __awaiter(void 0, void 0, void 0, function* () {
        var _a;
        const tbow = src_1.Items.get('Twisted bow');
        (0, vitest_1.expect)(tbow.equipment.attack_ranged).toEqual(70);
        (0, vitest_1.expect)(tbow.equipment.defence_crush).toEqual(0);
        (0, vitest_1.expect)(tbow.equipment.slot).toEqual(types_1.EquipmentSlot.TwoHanded);
        (0, vitest_1.expect)(tbow.wiki_name).toEqual('Twisted bow');
        (0, vitest_1.expect)(tbow.equipable_weapon).toEqual(true);
        (0, vitest_1.expect)(tbow.wiki_url).toEqual('https://oldschool.runescape.wiki/w/Twisted_bow');
        (0, vitest_1.expect)(tbow.examine).toEqual('A mystical bow carved from the twisted remains of the Great Olm.');
        const anglerHat = src_1.Items.get('Angler hat');
        (0, vitest_1.expect)(anglerHat.equipment.slot).toEqual(types_1.EquipmentSlot.Head);
        (0, vitest_1.expect)(anglerHat.equipable).toEqual(true);
        (0, vitest_1.expect)(anglerHat.equipable_by_player).toEqual(true);
        (0, vitest_1.expect)(anglerHat.equipable_weapon).toEqual(undefined);
        (0, vitest_1.expect)(anglerHat.equipment.attack_ranged).toEqual(0);
        const scep = src_1.Items.get(26950);
        (0, vitest_1.expect)(scep).toEqual(undefined);
        const scep2 = src_1.Items.get("Pharaoh's sceptre");
        (0, vitest_1.expect)(scep2.name).toEqual("Pharaoh's sceptre");
        (0, vitest_1.expect)(scep2.id).toEqual(9044);
        (0, vitest_1.expect)(scep2.equipable_by_player).toEqual(true);
        (0, vitest_1.expect)(scep2.equipable_weapon).toEqual(true);
        (0, vitest_1.expect)(scep2.equipable).toEqual(true);
        (0, vitest_1.expect)((_a = scep2.equipment) === null || _a === void 0 ? void 0 : _a.slot).toEqual(types_1.EquipmentSlot.Weapon);
        (0, vitest_1.expect)(src_1.Items.filter(i => i.name === "Pharaoh's sceptre").size).toEqual(1);
    }), 60000);
});
//# sourceMappingURL=Items.test.js.map