"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const vitest_1 = require("vitest");
const src_1 = require("../src");
(0, vitest_1.describe)('Utils', () => {
    (0, vitest_1.test)('toKMB checks', () => __awaiter(void 0, void 0, void 0, function* () {
        vitest_1.expect.assertions(10);
        (0, vitest_1.expect)(src_1.Util.toKMB(5)).toEqual('5');
        (0, vitest_1.expect)(src_1.Util.toKMB(1000)).toEqual('1k');
        (0, vitest_1.expect)(src_1.Util.toKMB(1500)).toEqual('1.5k');
        (0, vitest_1.expect)(src_1.Util.toKMB(1000000)).toEqual('1m');
        (0, vitest_1.expect)(src_1.Util.toKMB(1500000)).toEqual('1.5m');
        (0, vitest_1.expect)(src_1.Util.toKMB(15000000)).toEqual('15m');
        (0, vitest_1.expect)(src_1.Util.toKMB(150000000)).toEqual('150m');
        (0, vitest_1.expect)(src_1.Util.toKMB(1000000000)).toEqual('1b');
        (0, vitest_1.expect)(src_1.Util.toKMB(1200000000)).toEqual('1.2b');
        (0, vitest_1.expect)(src_1.Util.toKMB(50000000000)).toEqual('50b');
    }));
    (0, vitest_1.test)('negative toKMB checks', () => __awaiter(void 0, void 0, void 0, function* () {
        vitest_1.expect.assertions(10);
        (0, vitest_1.expect)(src_1.Util.toKMB(-5)).toEqual('-5');
        (0, vitest_1.expect)(src_1.Util.toKMB(-1000)).toEqual('-1k');
        (0, vitest_1.expect)(src_1.Util.toKMB(-1500)).toEqual('-1.5k');
        (0, vitest_1.expect)(src_1.Util.toKMB(-1000000)).toEqual('-1m');
        (0, vitest_1.expect)(src_1.Util.toKMB(-1500000)).toEqual('-1.5m');
        (0, vitest_1.expect)(src_1.Util.toKMB(-15000000)).toEqual('-15m');
        (0, vitest_1.expect)(src_1.Util.toKMB(-150000000)).toEqual('-150m');
        (0, vitest_1.expect)(src_1.Util.toKMB(-1000000000)).toEqual('-1b');
        (0, vitest_1.expect)(src_1.Util.toKMB(-1200000000)).toEqual('-1.2b');
        (0, vitest_1.expect)(src_1.Util.toKMB(-50000000000)).toEqual('-50b');
    }));
    (0, vitest_1.test)('KMB checks', () => __awaiter(void 0, void 0, void 0, function* () {
        vitest_1.expect.assertions(10);
        (0, vitest_1.expect)(src_1.Util.fromKMB('5')).toEqual(5);
        (0, vitest_1.expect)(src_1.Util.fromKMB('1k')).toEqual(1000);
        (0, vitest_1.expect)(src_1.Util.fromKMB('1.5k')).toEqual(1500);
        (0, vitest_1.expect)(src_1.Util.fromKMB('1m')).toEqual(1000000);
        (0, vitest_1.expect)(src_1.Util.fromKMB('1.5m')).toEqual(1500000);
        (0, vitest_1.expect)(src_1.Util.fromKMB('15m')).toEqual(15000000);
        (0, vitest_1.expect)(src_1.Util.fromKMB('150m')).toEqual(150000000);
        (0, vitest_1.expect)(src_1.Util.fromKMB('1b')).toEqual(1000000000);
        (0, vitest_1.expect)(src_1.Util.fromKMB('1.2b')).toEqual(1200000000);
        (0, vitest_1.expect)(src_1.Util.fromKMB('50b')).toEqual(50000000000);
    }));
    (0, vitest_1.test)('Brimestone chance calc', () => __awaiter(void 0, void 0, void 0, function* () {
        vitest_1.expect.assertions(6);
        (0, vitest_1.expect)(src_1.Util.getBrimKeyChanceFromCBLevel(725)).toEqual(50);
        (0, vitest_1.expect)(src_1.Util.getBrimKeyChanceFromCBLevel(321)).toEqual(56);
        (0, vitest_1.expect)(src_1.Util.getBrimKeyChanceFromCBLevel(303)).toEqual(59);
        (0, vitest_1.expect)(src_1.Util.getBrimKeyChanceFromCBLevel(123)).toEqual(95);
        (0, vitest_1.expect)(src_1.Util.getBrimKeyChanceFromCBLevel(28)).toEqual(1137);
        (0, vitest_1.expect)(src_1.Util.getBrimKeyChanceFromCBLevel(2)).toEqual(2021);
    }));
});
//# sourceMappingURL=Util.test.js.map