"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.checkThreshold = exports.withinThreshold = void 0;
const src_1 = require("../src");
function withinThreshold(source, target, epsilon = 5) {
    if (source === target)
        return true;
    return Math.abs(source - target) < (epsilon / 100) * target;
}
exports.withinThreshold = withinThreshold;
function checkThreshold(expectedRates, _result, numberDone) {
    const result = _result.bank;
    for (const [name, qty] of Object.entries(expectedRates)) {
        const item = src_1.Items.get(name);
        if (!item)
            throw new Error(`Missing item: ${name}`);
        if (!result[item.id]) {
            throw new Error(`Was no ${item.name}[${item.id}] in result, should have been.`);
        }
        expectedRates[item.id.toString()] = qty;
    }
    for (const [itemID, qty] of Object.entries(result)) {
        const item = src_1.Items.get(parseInt(itemID));
        if (!item)
            throw new Error(`Missing item with ID: ${itemID}`);
        const { id } = item;
        const expectedRate = expectedRates[id];
        if (!expectedRate)
            continue;
        const effectiveRate = numberDone / qty;
        if (!withinThreshold(effectiveRate, expectedRate, 10)) {
            throw new Error(`${item.name} wasn't within threshold. 1 in ${effectiveRate} instead of ${expectedRate}`);
        }
    }
}
exports.checkThreshold = checkThreshold;
//# sourceMappingURL=testUtil.js.map